function r = relcol(segs,t)
%
% relcol: computes the same column relation
% 
% On input:
%    segs: output of seginfo
%    t: avg column values must be this close to be same
% On output:
%   r: Boolean encoding of same column relation (0 -> False; 1-> True)
%
[m,n] = size(segs);
r = zeros(m,m);
for i1 = 1:m-1
  if segs(i1,1)>4
    for i2 = i1+1:m
	  if segs(i2,1)>4
        if abs(segs(i1,6)-segs(i2,6))<t
	      r(i1,i2) = 1;
	    end
	  end
    end
  end
end
